% A simple simulation using AR(1)
% Ensemble versus realization

% First set of realization for AR(1) with alpha=0.4 and sigma=0.2
% X(t+1) = alpha * X(t) + Error; Error ~ Normal (0,Variance)
num_realize=4;
num_values=100;

ar1param=0.4;
errsigma=0.5;
errmean=0;

for k=1:num_realize % Loop for multiple realizations of AR(1) model with identical parameters
    x(1)=normrnd(errmean,errsigma); % Initialize first value of series
    for i=1:(num_values-1) % Loop to calculate time series values using the given model
        x(i+1)=ar1param*x(i)+normrnd(errmean,errsigma);
    end
    for i=1:num_values % Loop to store time series values in each realization
        y(k,i)=x(i);
    end
end

figure
for i=1:4
    subplot(2,2,i)
    plot(y(i,:))
end


% Second set of realization for AR(1) with alpha=-0.3 and sigma=0.5
% X(t+1) = alpha * X(t) + Error; Error ~ Normal (0,Variance)
num_realize=4;
num_values=100;

ar1param=-0.3;
errsigma=0.2;
errmean=0;

for k=1:num_realize % Loop for multiple realizations of AR(1) model with identical parameters
    x(1)=normrnd(errmean,errsigma); % Initialize first value of series
    for i=1:(num_values-1) % Loop to calculate time series values using the given model
        x(i+1)=ar1param*x(i)+normrnd(errmean,errsigma);
    end
    for i=1:num_values % Loop to store time series values in each realization
        y(k,i)=x(i);
    end
end

figure
for i=1:4
    subplot(2,2,i)
    plot(y(i,:))
end


% Deterministic models

for i=1:num_values % Simulate purely deterministic time series
    det1(i)=20; % Constant Mean
    det2(i)=0.02*i; % Linear
    det3(i)=cos(i*2*3.1412/20); % Seasonal (Cosine)
    det4(i)=0.1*exp((i-15)/25); % Exponential
end

for i=1:num_values % Simulate time series with deterministic and AR(1) stochastic components
    ser1(i) = y(1,i) + det1(i); % Constant Mean + Random
    ser2(i) = y(1,i) + det2(i); % Linear + Random
    ser3(i) = y(1,i) + det3(i); % Seasonal (Cosine) + Random
    ser4(i) = y(1,i) + det4(i); % Exponential + Random
end

figure
subplot(221)
plot(ser1)
subplot(222)
plot(ser2)
subplot(223)
plot(ser3)
subplot(224)
plot(ser4)

